#
# This is the SPEC file for creating binary and source RPMs for the Qubes DB.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2013  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

Name:		qubes-db
Version:	4.1.9
Release:	1%{?dist}
Summary:	QubesDB tools

Group:		Qubes
License:	GPL
URL:		http://www.qubes-os.org/

BuildRequires:	gcc
BuildRequires:	qubes-libvchan-devel
BuildRequires:	systemd-devel
BuildRequires:  python%{python3_pkgversion}-devel
Requires:	qubes-libvchan
Source0:    %{name}-%{version}.tar.gz

%description
QubesDB management tools and daemon.

%package libs
Summary:	QubesDB libs
Group:		Qubes

%description libs
QubesDB client library.

%package devel
Summary:	QubesDB client header files
Group:		Qubes
Requires:	qubes-db-libs

%description devel
Header files for QubesDB client library and daemon protocol.

%package -n python%{python3_pkgversion}-qubesdb
Summary:    Python%{python3_pkgversion} bindings for QubesDB
Requires:   qubes-db-libs
%{?python_provide:%python_provide python%{python3_pkgversion}-qubesdb}

%description -n python%{python3_pkgversion}-qubesdb
Python3 bindings for QubesDB

%prep
%setup -q 

%build
%{?set_build_flags}
make %{?_smp_mflags} PYTHON=%{__python3} all

%install
make install \
         PYTHON=%{__python3} \
         DESTDIR=%{buildroot} \
         LIBDIR=%{_libdir} \
         BINDIR=%{_bindir} \
         SBINDIR=%{_sbindir}

%files
%doc
%{_bindir}/qubesdb-cmd
%{_bindir}/qubesdb-read
%{_bindir}/qubesdb-read-bool
%{_bindir}/qubesdb-write
%{_bindir}/qubesdb-rm
%{_bindir}/qubesdb-multiread
%{_bindir}/qubesdb-list
%{_bindir}/qubesdb-watch
%{_sbindir}/qubesdb-daemon

%files libs
%{_libdir}/libqubesdb.so

%files -n python%{python3_pkgversion}-qubesdb
%{python3_sitearch}/QubesDB-*egg-info
%{python3_sitearch}/qubesdb.*.so

%files devel
/usr/include/qubesdb.h
/usr/include/qubesdb-client.h

%changelog
* Tue Dec 08 2020 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qubesdb.git

* Tue Dec 08 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9b55f58
- version 4.1.9

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 93d64c3
- Add .gitlab-ci.yml

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 4e14dcd
- Use pkg-config to get BACKEND_VMM

* Fri Nov 13 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86ea7f0
- Set default BACKEND_VMM value to xen

* Wed Sep 16 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b2e7b58
- version 4.1.8

* Fri Aug 07 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - bcf3f91
- Update travis

* Sun May 17 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 15f4ff5
- version 4.1.7

* Sun May 17 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6a692c8
- Drop python2 support

* Sun May 17 2020 Neowutran <me@neowutran.ovh> - 3ba9487
- fix QubesOS/qubes-issues#5658, keep python2 in qubesdb.c

* Thu Apr 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 332c660
- version 4.1.6

* Fri Apr 17 2020 Ivan Kardykov <49684805+jevank@users.noreply.github.com> - 1443d57
- Fix uppercase write bug

* Fri Apr 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 31624ab
- version 4.1.5

* Sun Mar 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 91d9f1f
- daemon: zero out value before freeing

* Fri Jan 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9ca2a43
- version 4.1.4

* Thu Jan 16 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 15734b5
- qubesdb-read: handle wait option

* Sat Jan 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 4496e5f
- travis: switch to dom0 Fedora 31

* Sun Jan 05 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c931973
- version 4.1.3

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6cd3a63
- travis: switch to bionic

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5a4b664
- travis: add fc31 and bullseye

* Tue Sep 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 90fafcb
- version 4.1.2

* Tue Sep 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 143f3b5
- Fix permissions of header files

* Tue Sep 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3c45c12
- daemon: make systemd linking optional

* Mon Sep 16 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1674e90
- rpm: fix build dependencies

* Sun Aug 11 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a5667cd
- version 4.1.1

* Fri Aug 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - af25aa2
- python: fix gcc -Wsign-compare warnings

* Tue Jun 25 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 880b8df
- Fixes for C++

* Tue Jun 25 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - a7f20ba
- daemon: fix handling empty entries

* Tue Jun 25 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 91eda3b
- Daemon: fixed crash when trying to remove '/'

* Tue Jun 25 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - 03719a5
- Integration for OSS Fuzzer for db-daemon

* Tue Jun 25 2019 Marta Marczykowska-Górecka <marta.maria.gorecka@gmail.com> - acc7001
- Implement qubesdb_destroy

* Wed Jun 19 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 60473d0
- daemon: improve validation of message type over vchan

* Wed Jun 19 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bff235c
- daemon: improve handling stalling VM's daemon

* Mon Jun 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4343eff
- daemon: buffer vchan writes

* Mon Jun 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 01789a8
- daemon: limit amount of vchan writes triggered by remote side

* Wed Jun 12 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fbf9194
- daemon: fix dom0 daemon hang if VM's daemon disconnects

* Fri Apr 12 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 276a4a8
- travis: switch to xenial, add fc30

* Fri Apr 12 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f3bfa4c
- spec.in: use %{python3_pkgversion}

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cd1472f
- version 4.1.0

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 64c6428
- travis: update to R4.1

* Thu Feb 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0235b68
- rpm: drop direct xen-libs dependency

* Mon Oct 08 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1483c29
- version 4.0.10

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 32db462
- travis: add fc29

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 87de0cb
- rpm: add BR: gcc

* Sat Sep 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - adadcf4
- rpm: add missing BR: systemd-devel

* Fri Sep 07 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5b20e2b
- version 4.0.9

* Fri Aug 03 2018 unman <unman@thirdeyesecurity.org> - 3103035
- Remove wheezy and trusty builds. Consolidate Build-Depends

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 586bd96
- debian: unify Build-Depends

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f03ff8c
- travis: add fc28 and buster

* Wed Aug 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d7702c
- rpm: use build flags provided by the distribution

* Wed Jul 11 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6385bcc
- version 4.0.8

